@@ -1,5 +1,4 @@
-setClass(Class = "steepAscent", representation = representation(name = "character", X = "data.frame", 
-    response = "data.frame"))
+setClass(Class = "steepAscent", representation = representation(name = "character", X = "data.frame", response = "data.frame"))
 setMethod("response", "steepAscent", function(object) {
     out = object@response
     return(out)
