@@ -1,5 +1,5 @@
-contourPlot3 = function(x, y, z, response, data = NULL, xlim, ylim, zlim, main, xlab, ylab, zlab, border, sub, form = "linear", phi, theta, ticktype, 
-    col = 1, col.text, cex.axis, axes = TRUE, steps, factors, fun, plot) {
+contourPlot3 = function(x, y, z, response, data = NULL, main, xlab, ylab, zlab, border, form = "linear", col = 1, 
+    col.text, cex.axis, axes = TRUE, steps, factors) {
     DB = FALSE
     out = list()
     mdo = data
@@ -7,8 +7,6 @@ contourPlot3 = function(x, y, z, response, data = NULL, xlim, ylim, zlim, main,
     y.c = deparse(substitute(y))
     z.c = deparse(substitute(z))
     r.c = deparse(substitute(response))
-    if (missing(plot)) 
-        plot = TRUE
     if (missing(col)) 
         col = 1
     if (missing(col.text)) 
@@ -23,14 +21,8 @@ contourPlot3 = function(x, y, z, response, data = NULL, xlim, ylim, zlim, main,
         xlab = x.c
     if (missing(zlab)) 
         zlab = z.c
-    if (missing(ticktype)) 
-        ticktype = "detailed"
     if (missing(border)) 
         border = "white"
-    if (missing(phi)) 
-        phi = 30
-    if (missing(theta)) 
-        theta = -30
     if (missing(factors)) 
         factors = NULL
     if (missing(steps)) 
@@ -131,8 +123,8 @@ contourPlot3 = function(x, y, z, response, data = NULL, xlim, ylim, zlim, main,
     mtext(zlab, 1, at = 1.025, cex = 1.5)
     invisible(mat)
 }
-wirePlot3 = function(x, y, z, response, data = NULL, xlim, ylim, zlim, main, xlab, ylab, zlab, border, sub, form = "linear", phi, theta, ticktype, 
-    col = 1, col.text, cex.axis, axes = TRUE, steps, factors, fun, plot) {
+wirePlot3 = function(x, y, z, response, data = NULL, main, xlab, ylab, zlab, form = "linear", phi, theta, col = 1, 
+    steps, factors) {
     DB = FALSE
     out = list()
     mdo = data
@@ -140,14 +132,8 @@ wirePlot3 = function(x, y, z, response, data = NULL, xlim, ylim, zlim, main, xla
     y.c = deparse(substitute(y))
     z.c = deparse(substitute(z))
     r.c = deparse(substitute(response))
-    if (missing(plot)) 
-        plot = TRUE
     if (missing(col)) 
         col = 1
-    if (missing(col.text)) 
-        col.text = 1
-    if (missing(cex.axis)) 
-        cex.axis = 1
     if (missing(main)) 
         main = paste("Response Surface for", r.c)
     if (missing(ylab)) 
@@ -156,10 +142,6 @@ wirePlot3 = function(x, y, z, response, data = NULL, xlim, ylim, zlim, main, xla
         xlab = x.c
     if (missing(zlab)) 
         zlab = z.c
-    if (missing(ticktype)) 
-        ticktype = "detailed"
-    if (missing(border)) 
-        border = "white"
     if (missing(phi)) 
         phi = 30
     if (missing(theta)) 
@@ -246,8 +228,8 @@ wirePlot3 = function(x, y, z, response, data = NULL, xlim, ylim, zlim, main, xla
     }
     maxim = max(mat, na.rm = TRUE) * acc
     minim = min(mat, na.rm = TRUE) * acc
-    per = persp(x = seq(0, acc, length = acc), y = seq(0, acc * sca, length = ncmat), mat * acc, phi = .phi, theta = .theta, scale = TRUE, col = "transparent", 
-        border = FALSE, box = FALSE, main = main, xlab = xlab, ylab = ylab)
+    per = persp(x = seq(0, acc, length = acc), y = seq(0, acc * sca, length = ncmat), mat * acc, phi = .phi, theta = .theta, 
+        scale = TRUE, col = "transparent", border = FALSE, box = FALSE, main = main, xlab = xlab, ylab = ylab)
     lineList = contourLines(x = seq(0, acc, length = acc), y = seq(0, acc * sca, length = ncmat), mat)
     for (i in seq(along = lineList)) lines(trans3d(lineList[[i]]$x, lineList[[i]]$y, z = minim, pmat = per))
     if (.phi < 90) {
@@ -265,15 +247,17 @@ wirePlot3 = function(x, y, z, response, data = NULL, xlim, ylim, zlim, main, xla
     if (.theta > 156 && .theta < 323) {
         lines(trans3d(x = acc, y = 0, z = minim:maxim, pmat = per), lty = 2)
     }
-    lines(trans3d(x = seq(0, acc/2, length = 10), y = seq(0, acc * sca, length = 10), z = minim, pmat = per), lty = 1, lwd = 2)
-    lines(trans3d(x = seq(acc, acc/2, length = 10), y = seq(0, acc * sca, length = 10), z = minim, pmat = per), lty = 1, lwd = 2)
+    lines(trans3d(x = seq(0, acc/2, length = 10), y = seq(0, acc * sca, length = 10), z = minim, pmat = per), lty = 1, 
+        lwd = 2)
+    lines(trans3d(x = seq(acc, acc/2, length = 10), y = seq(0, acc * sca, length = 10), z = minim, pmat = per), lty = 1, 
+        lwd = 2)
     lines(trans3d(x = 0:acc, y = 0, z = minim, pmat = per), lty = 1, lwd = 2)
     text(trans3d(x = acc/2 + acc/50, y = acc * sca + acc * sca/50, z = minim, pmat = per), labels = xlab, lwd = 2)
     text(trans3d(x = -acc/50, y = -acc * sca/50, z = minim, pmat = per), labels = ylab, lwd = 2)
     text(trans3d(x = acc + acc/50, 0, z = minim, pmat = per), labels = zlab, cex = 1, lwd = 2)
     par(new = TRUE)
-    persp(x = seq(0, acc, length = acc), y = seq(0, acc * sca, length = ncmat), mat * acc, phi = .phi, theta = .theta, scale = TRUE, col = color[facetcol], 
-        border = FALSE, box = FALSE)
+    persp(x = seq(0, acc, length = acc), y = seq(0, acc * sca, length = ncmat), mat * acc, phi = .phi, theta = .theta, 
+        scale = TRUE, col = color[facetcol], border = FALSE, box = FALSE)
     if (.phi > 0) {
         lines(trans3d(x = seq(0, acc/2, length = 10), y = seq(0, acc * sca, length = 10), z = maxim, pmat = per), lty = 2)
         lines(trans3d(x = seq(acc, acc/2, length = 10), y = seq(0, acc * sca, length = 10), z = maxim, pmat = per), lty = 2)
@@ -298,9 +282,11 @@ wirePlot3 = function(x, y, z, response, data = NULL, xlim, ylim, zlim, main, xla
         temp[leglevel == 0] = " "
         legpretty = paste(temp, legpretty, sep = "")
         if (.theta <= 180) 
-            legend("topright", inset = 0.02, legend = paste(">", legpretty), col = legcol, bg = "white", pt.cex = 1.5, cex = 0.75, pch = 15)
+            legend("topright", inset = 0.02, legend = paste(">", legpretty), col = legcol, bg = "white", pt.cex = 1.5, 
+                cex = 0.75, pch = 15)
         if (.theta > 180) 
-            legend("topleft", inset = 0.02, legend = paste(">", legpretty), col = legcol, bg = "white", pt.cex = 1.5, cex = 0.75, pch = 15)
+            legend("topleft", inset = 0.02, legend = paste(">", legpretty), col = legcol, bg = "white", pt.cex = 1.5, 
+                cex = 0.75, pch = 15)
     }
     invisible(mat)
 } 
